==> gmx_MMPBSA-1.4.1.tar.gz: gmx_MMPBSA-1.4.1/README.md <==
[![pypi](https://img.shields.io/pypi/v/gmx-MMPBSA)](https://pypi.org/project/gmx-MMPBSA/)
[![support](https://img.shields.io/badge/support-JetBrains-brightgreen)](https://www.jetbrains.com/?from=gmx_MMPBSA)
[![python](https://img.shields.io/badge/python-v3.x-blue)]()
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4569307.svg)](http://doi.org/10.5281/zenodo.4569307)

# Welcome to gmx_MMPBSA!
gmx_MMPBSA is a new tool based on AMBER's MMPBSA.py aiming to perform end-state free energy calculations with GROMACS 
files.

**Please see the documentation [here](https://valdes-tresanco-ms.github.io/gmx_MMPBSA/)**

## Citing us

At the moment we only have Zenodo [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4569307.svg)](https://doi.org/10.5281/zenodo.4569307)

Cite as:

Mario S. Valdés Tresanco, Mario E. Valdes-Tresanco, Pedro A. Valiente, & Ernesto Moreno Frías. (2021, March 22).  
gmx_MMPBSA (Version v1.4.0). Zenodo. http://doi.org/10.5281/zenodo.4569307

**We will have the article available soon**

Please also consider citing MMPBSA.py's paper:

**MMPBSA.py: An Efficient Program for End-State Free Energy Calculations**. Bill R. Miller, T. Dwight McGee, Jason M.
Swails, Nadine Homeyer, Holger Gohlke, and Adrian E. Roitberg. _Journal of Chemical Theory and Computation_, 2012 8 
(9), 3314-3321. [**DOI:** 10.1021/ct300418h][1]

---------------------------------------

Authors:
- Mario Sergio Valdés Tresanco, PhD Student. _University of Medellin, Colombia_
- Mario Ernesto Valdés Tresanco, PhD Student. _University of Calgary, Canada._
- Pedro Alberto Valiente, PhD. _University of Toronto, Canada_
- Ernesto Moreno Frías, PhD. _University of Medellin, Colombia_

---------------------------------------

==> gmx_MMPBSA-1.4.2.tar.gz: gmx_MMPBSA-1.4.2/README.md <==
[![pypi](https://img.shields.io/pypi/v/gmx-MMPBSA)](https://pypi.org/project/gmx-MMPBSA/)
[![support](https://img.shields.io/badge/support-JetBrains-brightgreen)](https://www.jetbrains.com/?from=gmx_MMPBSA)
[![python](https://img.shields.io/badge/python-v3.x-blue)]()
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4569307.svg)](http://doi.org/10.5281/zenodo.4569307)

# Welcome to gmx_MMPBSA!
gmx_MMPBSA is a new tool based on AMBER's MMPBSA.py aiming to perform end-state free energy calculations with GROMACS 
files.

**Please see the documentation [here](https://valdes-tresanco-ms.github.io/gmx_MMPBSA/)**

## Citing us

At the moment we only have Zenodo [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4569307.svg)](https://doi.org/10.5281/zenodo.4569307)

Cite as:

Mario S. Valdés Tresanco, Mario E. Valdes-Tresanco, Pedro A. Valiente, & Ernesto Moreno Frías.  
gmx_MMPBSA (Version v1.4.1). Zenodo. http://doi.org/10.5281/zenodo.4569307

**We will have the article available soon**

Please also consider citing MMPBSA.py's paper:

**MMPBSA.py: An Efficient Program for End-State Free Energy Calculations**. Bill R. Miller, T. Dwight McGee, Jason M.
Swails, Nadine Homeyer, Holger Gohlke, and Adrian E. Roitberg. _Journal of Chemical Theory and Computation_, 2012 8 
(9), 3314-3321. (https://pubs.acs.org/doi/10.1021/ct300418h)

---------------------------------------

Authors:
- Mario Sergio Valdés Tresanco, PhD Student. _University of Medellin, Colombia_
- Mario Ernesto Valdés Tresanco, PhD Student. _University of Calgary, Canada._
- Pedro Alberto Valiente, PhD. _University of Toronto, Canada_
- Ernesto Moreno Frías, PhD. _University of Medellin, Colombia_

---------------------------------------
